$! Get_Root_Method.COM
$!
$! Malcolm MacArthur (malcolm@neverness.freeserve.co.uk)
$! 11-Jan-2002
$!
$! Determine DECwindows version for root window display. The way DECwindows
$! handles the root display changed in V1.2-5 and above of Motif (it now
$! works in a way that "standard" XV can handle, which means it breaks the
$! old VMS-specific code).
$!
$! This command file does its best to check the DECwindows version, and 
$! returns the following values in the job logical name XV_ROOT_METHOD:
$!   "STANDARD"   - use standard XV code. For Motif V1.2-5 and above.
$!   "DECWINDOWS" - use DECwindows specific code. For Motif V1.2-4 and below.
$!
$! A job logical name is used because MMS (AFAIK) would spawn this check
$! off in a subprocess. A global symbol would therefore be lost on subprocess
$! exit.
$!
$! Check for SYS$UPDATE:DECW$GET_IMAGE_VERSION.COM. If it doesn't exist,
$! then we'll assume that we have a pre 1.2-5 version of DECwindows.
$!
$ USE_NORMAL_ROOT_WINDOW_METHOD = "FALSE"
$ If F$Search("SYS$UPDATE:DECW$GET_IMAGE_VERSION.COM") .eqs. ""
$   Then
$       Write Sys$Output "SYS$UPDATE:DECW$GET_IMAGE_VERSION.COM not found."
$       Write Sys$Output ""
$       Write Sys$Output "Defaulting to using VMS-specific pseudo_root() function"
$
$   Else
$!
$!  Get version of SYS$SHARE:DECW$XLIBSHR.EXE
$!
$!  Check for existence of SYS$SHARE:DECW$XLIBSHR.EXE
$       If F$Search("SYS$SHARE:DECW$XLIBSHR.EXE") .eqs. ""
$           Then
$!    Shouldn't happen ;-)
$               Write Sys$Output "Can't find SYS$SHARE:DECW$XLIBSHR.EXE"
$               Write Sys$Output "(This should never happen...)"
$               Write Sys$Output -
                    "Defaulting to using VMS-specific pseudo_root() function"
$               Write Sys$Output ""
$           Else
$!    Get DECwindows version
$               @ SYS$UPDATE:DECW$GET_IMAGE_VERSION SYS$SHARE:DECW$XLIBSHR.EXE DECW$VERSION
$               temp = F$Element(1," ",decw$version)
$               If temp .eqs. " "
$                   Then
$                       Write Sys$Output "? DECwindows version number is in unknown format"
$                       Write Sys$Output "(""",decw$version,""")"
$                       Write Sys$Output ""
$                       Write Sys$Output "Defaulting to using VMS-specific pseudo_root() function"
$                       Write Sys$Output ""
$                   Else
$                       decw$version_type  = F$Extract(0,1,temp)
$                       decw$major_version = F$Element(0,".",temp) - decw$version_type
$                       decw$minor_version = F$Element(0,"-",F$Element(1,".",temp))
$                       decw$revision      = F$Extract(0,1,F$Element(1,"-",F$Element(1,".",temp)))
$                       If decw$version_type .nes. "V"
$                           Then
$                               Write Sys$Output "WARNING! You are using a non-standard/field test/experimental"
$                               Write Sys$Output "version of DECwindows ("+decw$version_type+decw$major_version+ "."+decw$minor_version+"-"+decw$revision+")"
$                               Write Sys$Output "As a result, the version checking may produce"
$                               Write Sys$Output "unexpected results."
$                               Write Sys$Output ""
$                       Endif
$                       If decw$major_version .gt. 1
$                           Then
$! Assuming future major versions use the 'Unix' method...              
$                               USE_NORMAL_ROOT_WINDOW_METHOD = "TRUE"
$                           Else ! Version 1
$                               If decw$minor_version .gt. 2
$                                   Then
$! Assuming future minor versions use the 'Unix' method...              
$                                       USE_NORMAL_ROOT_WINDOW_METHOD = "TRUE"
$                                   Else
$                                       If decw$minor_version .eq. 2
$                                           Then
$                                               If decw$revision .ge. 5
$                                                   Then
$! Assuming future revisions use the 'Unix' method...              
$                                                       USE_NORMAL_ROOT_WINDOW_METHOD = "TRUE"
$                                               Endif ! decw$revision .ge. 5
$                                       Endif   ! decw$minor_version .eq. 2
                                Endif     ! decw$minor_version .gt. 2
$                       Endif       ! decw$major_version .gt. 1
$               Endif         ! temp .nes. " "
$       Endif           ! F$Search("SYS$SHARE:DECW$XLIBSHR.EXE") .eqs. ""
$ Endif             ! F$Search("SYS$UPDATE:DECW$GET_IMAGE_VERSION.COM")
$ If USE_NORMAL_ROOT_WINDOW_METHOD
$   Then
$       Write Sys$Output "Will use the standard XV functions to determine"
$       Write Sys$Output "the root window ID. Note that this means that this"
$       Write Sys$Output "version of XV may be unable to display to the root"
$       Write Sys$Output "window on older VMS systems"
$       Write Sys$Output ""
$       Define /Job XV_ROOT_METHOD "STANDARD"
$   Else
$       Write Sys$Output "Will use the pseudo_root() function in VMS.C to determine"
$       Write Sys$Output "the root window ID. Note that this means that this"
$       Write Sys$Output "version of XV may be unable to display to the root"
$       Write Sys$Output "window on non-VMS systems and newer DECwindows versions"
$       Write Sys$Output ""
$       Define /Job XV_ROOT_METHOD "DECWINDOWS"
$ Endif
$
$ Exit
